@@ -59,7 +59,7 @@ def timer(logger):
             result = func(*args, **kwargs)
             t2 = time.time() - t1
             print('{} ran in: {} sec'.format(func.__name__, t2))
-            logger.info('{} ran in: {} sec'.format(func.__name__, t2))
+            logger.warning('{} ran in: {} sec'.format(func.__name__, t2))
             return result
         
         return wrapper
@@ -82,7 +82,7 @@ def azureml_timer(logger, run):
                                 "duration_in_sec": t2,
                                 "method_name":func.__name__
                                 }
-            logger.info('{} ran in: {} sec'.format(func.__name__, t2), custom_dimensions)
+            logger.warning('{} ran in: {} sec'.format(func.__name__, t2), custom_dimensions)
             return result
         
         return wrapper
